Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(56)

Unified Diff: third_party/WebKit/Source/core/html/forms/ColorChooser.h

Issue 2858493002: Rename AXObject to AXObjectImpl in modules/ and web/ (Closed)
Patch Set: Reverted unexpected change to blink rename merge helper Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/forms/ColorChooser.h
diff --git a/third_party/WebKit/Source/core/html/forms/ColorChooser.h b/third_party/WebKit/Source/core/html/forms/ColorChooser.h
index 6e289954248d40686008758db9cdf45ce895d2b1..c3054a6ce7ba1851eb570276bd5e6b535c4d06a6 100644
--- a/third_party/WebKit/Source/core/html/forms/ColorChooser.h
+++ b/third_party/WebKit/Source/core/html/forms/ColorChooser.h
@@ -35,7 +35,7 @@
namespace blink {
-class AXObject;
+class AXObjectImpl;
class Color;
class CORE_EXPORT ColorChooser : public GarbageCollectedMixin {
@@ -46,8 +46,8 @@ class CORE_EXPORT ColorChooser : public GarbageCollectedMixin {
virtual void SetSelectedColor(const Color&) {}
virtual void EndChooser() {}
- // Returns a root AXObject in the ColorChooser if it's available.
- virtual AXObject* RootAXObject() = 0;
+ // Returns a root AXObjectImpl in the ColorChooser if it's available.
+ virtual AXObjectImpl* RootAXObject() = 0;
};
} // namespace blink

Powered by Google App Engine
This is Rietveld 408576698